@@ -26,6 +26,13 @@ $server->tool(
     return "Echo: $args->{msg}";
   }
 );
+$server->prompt(
+  name        => 'echo',
+  description => 'A prompt to demonstrate the echo tool',
+  code        => sub ($prompt, $args) {
+    return 'Use the echo tool with the message "Hello, World!"';
+  }
+);
 
 any '/mcp' => $server->to_action;
 
