@@ -4,13 +4,15 @@ use Mojo::Base -base, -signatures;
 use List::Util     qw(first);
 use Mojo::JSON     qw(false true);
 use MCP::Constants qw(INVALID_PARAMS INVALID_REQUEST METHOD_NOT_FOUND PARSE_ERROR PROTOCOL_VERSION);
+use MCP::Prompt;
 use MCP::Server::Transport::HTTP;
 use MCP::Server::Transport::Stdio;
 use MCP::Tool;
 use Scalar::Util qw(blessed);
 
-has name  => 'PerlServer';
-has tools => sub { [] };
+has name    => 'PerlServer';
+has prompts => sub { [] };
+has tools   => sub { [] };
 has 'transport';
 has version => '1.0.0';
 
@@ -28,6 +30,13 @@ sub handle ($self, $request, $context) {
     elsif ($method eq 'ping') {
       return _jsonrpc_response({}, $id);
     }
+    elsif ($method eq 'prompts/list') {
+      my $result = $self->_handle_prompts_list;
+      return _jsonrpc_response($result, $id);
+    }
+    elsif ($method eq 'prompts/get') {
+      return $self->_handle_prompts_get($request->{params} // {}, $id, $context);
+    }
     elsif ($method eq 'tools/list') {
       my $result = $self->_handle_tools_list;
       return _jsonrpc_response($result, $id);
@@ -44,6 +53,12 @@ sub handle ($self, $request, $context) {
   return undef;
 }
 
+sub prompt ($self, %args) {
+  my $prompt = MCP::Prompt->new(%args);
+  push @{$self->prompts}, $prompt;
+  return $prompt;
+}
+
 sub to_action ($self) {
   $self->transport(my $http = MCP::Server::Transport::HTTP->new(server => $self));
   return sub ($c) { $http->handle_request($c) };
@@ -63,11 +78,33 @@ sub tool ($self, %args) {
 sub _handle_initialize ($self, $params) {
   return {
     protocolVersion => PROTOCOL_VERSION,
-    capabilities    => {tools => {}},
-    serverInfo      => {name  => $self->name, version => $self->version}
+    capabilities    => {prompts => {},          tools   => {}},
+    serverInfo      => {name    => $self->name, version => $self->version}
   };
 }
 
+sub _handle_prompts_list ($self) {
+  my @prompts;
+  for my $prompt (@{$self->prompts}) {
+    my $info = {name => $prompt->name, description => $prompt->description, arguments => $prompt->arguments};
+    push @prompts, $info;
+  }
+
+  return {prompts => \@prompts};
+}
+
+sub _handle_prompts_get ($self, $params, $id, $context) {
+  my $name = $params->{name}      // '';
+  my $args = $params->{arguments} // {};
+  return _jsonrpc_error(METHOD_NOT_FOUND, "Prompt '$name' not found")
+    unless my $prompt = first { $_->name eq $name } @{$self->prompts};
+  return _jsonrpc_error(INVALID_PARAMS, 'Invalid arguments') if $prompt->validate_input($args);
+
+  my $result = $prompt->call($args, $context);
+  return $result->then(sub { _jsonrpc_response($_[0], $id) }) if blessed($result) && $result->isa('Mojo::Promise');
+  return _jsonrpc_response($result, $id);
+}
+
 sub _handle_tools_call ($self, $params, $id, $context) {
   my $name = $params->{name}      // '';
   my $args = $params->{arguments} // {};
@@ -113,6 +150,25 @@ MCP::Server - MCP server implementation
 
   my $server = MCP::Server->new(name => 'MyServer');
 
+  $server->tool(
+    name         => 'echo',
+    description  => 'Echo the input text',
+    input_schema => {type => 'object', properties => {msg => {type => 'string'}}, required => ['msg']},
+    code         => sub ($tool, $args) {
+      return "Echo: $args->{msg}";
+    }
+  );
+
+  $server->prompt(
+    name        => 'echo',
+    description => 'A prompt to demonstrate the echo tool',
+    code        => sub ($prompt, $args) {
+      return 'Use the echo tool with the message "Hello, World!"';
+    }
+  );
+
+  $server->to_stdio;
+
 =head1 DESCRIPTION
 
 L<MCP::Server> is an MCP (Model Context Protocol) server.
@@ -159,6 +215,17 @@ L<MCP::Tool> inherits all methods from L<Mojo::Base> and implements the followin
 
 Handle a JSON-RPC request and return a response.
 
+=head2 prompt
+
+  my $prompt = $server->prompt(
+    name        => 'my_prompt',
+    description => 'A sample prompt',
+    arguments   => [{name => 'foo', description => 'Whatever', required => 1}],
+    code        => sub ($prompt, $args) { ... }
+  );
+
+Register a new prompt with the server.
+
 =head2 to_action
 
   my $action = $server->to_action;
